
EASY ZIP
====

## What is it?

EASY ZIP is a simple tool to create zip archives. Whatever you zip from file or folder, it will be zipped in a single archive.
You can also create a password protected zip archive.

## How to use it?

### Create a zip archive

```

import easyzip

easyzip.zip('path/to/file/or/folder', 'path/to/zip/archive.zip', compressLevel = 9, password = 'hahahahaha')

```
